@@ -59,6 +59,13 @@
 #include "game.h"
 #include "window.h"
 
+#if 0
+/* String reserve */
+N_("Solitaire")
+N_("GNOME Solitaire")
+N_("About Solitaire")
+#endif /* 0 */
+
 typedef struct {
   AisleriotWindow *window;
   char *variation;
@@ -153,11 +160,17 @@ osso_hw_event_cb (osso_hw_state_t *state,
   if (data->program == NULL)
     return;
 
+  games_conf_save ();
+
+  if (state->memory_low_ind) {
+    /* Run garbage collection */
+    scm_gc ();
+  }
+
 #if GNOME_ENABLE_DEBUG
   if (state->shutdown_ind) {
     g_print ("Going to shut down\n");
   } else if (state->save_unsaved_data_ind) {
-    g_print ("Should save unsaved data\n");
   } else if (state->memory_low_ind) {
     g_print ("Should try to free some memory\n");
   } else if (state->system_inactivity_ind) {
@@ -195,6 +208,9 @@ sync_is_topmost_cb (HildonProgram *program,
   if (hildon_program_get_is_topmost (program)) {
     hildon_program_set_can_hibernate (program, FALSE);
   } else {
+    /* Ensure settings are saved to disk */
+    games_conf_save ();
+
     /* FIXMEchpe: save state here */
 
     hildon_program_set_can_hibernate (program, TRUE);
@@ -277,6 +293,20 @@ main_prog (void *closure, int argc, char *argv[])
   g_option_context_add_group (option_context, clutter_get_option_group_without_init ());
 #endif
 
+#if defined(HAVE_HILDON) && defined(HAVE_MAEMO_5)
+  {
+    char *rc_file;
+
+    /* Note: we have to use gtk_rc_add_default_file() before calling gtk_init() (via
+     * g_option_context_parse()) rather than parsing the file directly afterward, in
+     * order to get priority over the theme.
+     */
+    rc_file = games_runtime_get_file (GAMES_RUNTIME_GAME_DATA_DIRECTORY, "gtkrc-maemo");
+    gtk_rc_add_default_file (rc_file);
+    g_free (rc_file);
+  }
+#endif /* HAVE_HILDON && HAVE_MAEMO_5 */
+
   retval = g_option_context_parse (option_context, &argc, &argv, &error);
   g_option_context_free (option_context);
 
@@ -326,12 +356,12 @@ main_prog (void *closure, int argc, char *argv[])
 
   games_stock_init ();
 
-  data.window = AISLERIOT_WINDOW (aisleriot_window_new ());
+  gtk_window_set_default_icon_name (data.freecell ? "gnome-freecell" : "gnome-aisleriot");
+
+  data.window = AISLERIOT_WINDOW (aisleriot_window_new (data.freecell));
   g_signal_connect (data.window, "destroy",
 		    G_CALLBACK (gtk_main_quit), NULL);
 
-  gtk_window_set_default_icon_name (data.freecell ? "gnome-freecell" : "gnome-aisleriot");
-
 #ifdef WITH_SMCLIENT
   sm_client = egg_sm_client_get ();
   g_signal_connect (sm_client, "save-state",
@@ -374,7 +404,6 @@ main_prog (void *closure, int argc, char *argv[])
 #endif /* HAVE_HILDON */
 
   if (data.freecell) {
-    aisleriot_window_set_freecell_mode (data.window);
     aisleriot_window_set_game (data.window, FREECELL_VARIATION, data.seed);
   } else {
     aisleriot_window_set_game (data.window, data.variation, data.seed);
