@@ -12,9 +12,9 @@ import gtk.gdk
 
 import gtkui
 import glchess.ui
+from glchess.i18n import C_
 
 class GtkServerList:
-    __gui = None
 
     def __init__(self, gui):
         self.__gui = gui
@@ -74,7 +74,8 @@ class GtkServerList:
 
 class GtkNewGameDialog:
     """
-    """    
+    """
+
     def __init__(self, mainUI, aiModel, game = None):
         """Constructor for a new game dialog.
         
@@ -410,7 +411,8 @@ class GtkNewGameDialog:
 
 class GtkLoadGameDialog:
     """
-    """    
+    """
+
     def __init__(self, mainUI):
         """
         """
@@ -485,6 +487,7 @@ class GtkLoadGameDialog:
 class GtkSaveGameDialog:
     """
     """
+
     def __init__(self, mainUI, view, path = None):
         """
         """
@@ -511,12 +514,14 @@ class GtkSaveGameDialog:
         
         # Filter out non PGN files by default
         pgnFilter = gtk.FileFilter()
-        pgnFilter.set_name('PGN files')
+        # Translators: Save Game Dialog: Name of filter to show only PGN files
+        pgnFilter.set_name(_('PGN files'))
         pgnFilter.add_pattern('*.pgn')
         chooser.add_filter(pgnFilter)
         
         allFilter = gtk.FileFilter()
-        allFilter.set_name('All files')
+        # Translators: Save Game Dialog: Name of filter to show all files
+        allFilter.set_name(_('All files'))
         allFilter.add_pattern('*')
         chooser.add_filter(allFilter)
         
@@ -567,6 +572,7 @@ class GtkSaveGameDialog:
 class GtkPreferencesDialog:
     """
     """
+
     def __init__(self, mainUI):
         """Constructor for the preferences dialog.
         
@@ -616,19 +622,15 @@ class GtkPreferencesDialog:
         promotionModel = gtk.ListStore(str, str)
         widget = self.__gui.get_object('promotion_type_combo')
         widget.set_model(promotionModel)
-                          # Translators: Promotion Combo: Promote to a queen. Do not translate the 'chess-piece|' text.
-        promotion_list = [('queen',  _('chess-piece|Queen')),
-                          # Translators: Promotion Combo: Promote to a knight. Do not translate the 'chess-piece|' text.
-                          ('knight', _('chess-piece|Knight')),
-                          # Translators: Promotion Combo: Promote to a rook. Do not translate the 'chess-piece|' text.
-                          ('rook',   _('chess-piece|Rook')),
-                          # Translators: Promotion Combo: Promote to a bishop. Do not translate the 'chess-piece|' text.
-                          ('bishop', _('chess-piece|Bishop'))]
+                          # Translators: Promotion Combo: Promote to a queen
+        promotion_list = [('queen',  C_('chess-piece', 'Queen')),
+                          # Translators: Promotion Combo: Promote to a knight
+                          ('knight', C_('chess-piece', 'Knight')),
+                          # Translators: Promotion Combo: Promote to a rook
+                          ('rook',   C_('chess-piece', 'Rook')),
+                          # Translators: Promotion Combo: Promote to a bishop
+                          ('bishop', C_('chess-piece', 'Bishop'))]
         for (key, label) in promotion_list:
-            try:
-                label = label.split('|', 1)[1]
-            except IndexError:
-                pass
             iter = promotionModel.append()
             promotionModel.set(iter, 0, label, 1, key)
             
