@@ -1,20 +1,20 @@
 /* 
-   Copyright © 2004 Callum McKenzie
-   Copyright © 2007, 2008 Christian Persch
+  Copyright © 2004 Callum McKenzie
+  Copyright © 2007, 2008 Christian Persch
 
-   This library is free software; you can redistribute it and'or modify
-   it under the terms of the GNU Library General Public License as published 
-   by the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+  This library is free software: you can redistribute it and/or modify
+  it under the terms of the GNU Lesser General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+  You should have received a copy of the GNU Lesser General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 /* Authors:   Callum McKenzie <callum@physics.otago.ac.nz> */
 
@@ -396,6 +396,20 @@ games_card_images_set_cache_mode (GamesCardImages * images,
   images->cache_mode = mode;
 }
 
+/**
+ * games_card_images_drop_cache:
+ * @images: a #GamesCardImages
+ *
+ * Clears the image cache.
+ */
+void
+games_card_images_drop_cache (GamesCardImages *images)
+{
+  g_return_if_fail (GAMES_IS_CARD_IMAGES (images));
+
+  games_card_images_clear_cache (images);
+}
+
 /**
  * games_card_images_set_drawable:
  * @images:
