@@ -21,13 +21,12 @@
 
 #include <config.h>
 
-#include <math.h>
-
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include "games-scores-dialog.h"
 #include "games-scores-dialog-private.h"
+#include "games-gtk-compat.h"
 
 G_DEFINE_TYPE (GamesScoresDialog, games_scores_dialog, GTK_TYPE_DIALOG);
 
@@ -87,10 +86,8 @@ static void games_scores_dialog_add_category (GamesScoresDialog *self,
 static void games_scores_dialog_load_categories (GamesScoresCategory *cat, 
 						 GamesScoresDialog *self) 
 {
-    /* Note the Q_ here, this is so we can use context tags on similar
-     * names. (Medium is one that can cause trouble for translators 
-     * in different contexts.) */
-    games_scores_dialog_add_category (self, cat->key, Q_(cat->name));
+    /* category->name is already translated here! */
+    games_scores_dialog_add_category (self, cat->key, cat->name);
 }
 
 /**
@@ -135,10 +132,12 @@ static void games_scores_dialog_set_style (GamesScoresDialog *self,
 static void games_scores_dialog_set_category (GamesScoresDialog *self, 
 					      const gchar *key) 
 {
-  gint idx;
+  gpointer value;
+  int idx;
+
+  value = g_hash_table_lookup (self->_priv->categories, key);
+  idx = GPOINTER_TO_INT (value);
 
-  idx = GPOINTER_TO_SIZE (g_hash_table_lookup (self->_priv->categories, 
-						key));
   self->_priv->preservehilight = TRUE;
   gtk_combo_box_set_active (GTK_COMBO_BOX (self->_priv->combo), idx);
 }
@@ -165,9 +164,9 @@ GtkWidget * games_scores_dialog_new (GtkWindow *parent_window, GamesScores *scor
   gtk_window_set_title (GTK_WINDOW (dialog), title);
   gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent_window));
 
-  games_scores_category_foreach (scores, 
-				 (GamesScoresCategoryForeachFunc) games_scores_dialog_load_categories, 
-				 dialog);
+  _games_scores_category_foreach (scores, 
+                                  (GamesScoresCategoryForeachFunc) games_scores_dialog_load_categories,
+                                  dialog);
 
   if (dialog->_priv->catcounter <= 1) {
     gtk_widget_hide (dialog->_priv->catbar);
@@ -272,7 +271,7 @@ static void games_scores_dialog_redraw (GamesScoresDialog *self) {
     case GAMES_SCORES_STYLE_TIME_ASCENDING:
     case GAMES_SCORES_STYLE_TIME_DESCENDING:
       dscore = ((GamesScore *)scorelist->data)->value.time_double;
-      score = rint (100*(dscore));
+      score = (int) (100.0 * dscore + 0.5);
       /* Translators: this is for a minutes, seconds time display. */
       ss = g_strdup_printf (_("%dm %ds"), score/100, score%100);
       break; 
@@ -412,7 +411,7 @@ void games_scores_dialog_set_hilight (GamesScoresDialog *self, guint pos)
 void games_scores_dialog_set_buttons (GamesScoresDialog *self, guint buttons)
 {
   /* Remove an existing buttons. */
-  gtk_container_foreach (GTK_CONTAINER (GTK_DIALOG (self)->action_area),
+  gtk_container_foreach (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (self))),
                          (GtkCallback) (gtk_widget_destroy), NULL);
 
   /* The default is a single close button, suitable for the scores
@@ -475,7 +474,7 @@ static void games_scores_dialog_init (GamesScoresDialog *self)
 
   gtk_dialog_set_has_separator (GTK_DIALOG (self), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (self), 5);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (self)->vbox), 2);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (self))), 2);
 
   g_signal_connect (G_OBJECT (self), "show", 
 		      G_CALLBACK (games_scores_dialog_show), NULL);
@@ -484,8 +483,8 @@ static void games_scores_dialog_init (GamesScoresDialog *self)
 
   vbox = gtk_vbox_new (FALSE, 6);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
-  gtk_box_pack_end (GTK_BOX (GTK_DIALOG (self)->vbox), vbox, TRUE, TRUE, 
-                    0);
+  gtk_box_pack_end (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (self))),
+                    vbox, TRUE, TRUE, 0);
 
   scroll = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
@@ -514,6 +513,7 @@ static void games_scores_dialog_init (GamesScoresDialog *self)
 			FALSE, FALSE, 0);	
  
   self->_priv->combo = gtk_combo_box_new_text ();
+  gtk_combo_box_set_focus_on_click (GTK_COMBO_BOX (self->_priv->combo), FALSE);
   gtk_box_pack_start (GTK_BOX (self->_priv->catbar), 
 			self->_priv->combo, TRUE, TRUE, 0);
   gtk_label_set_mnemonic_widget (GTK_LABEL (self->_priv->label), self->_priv->combo);
@@ -557,6 +557,8 @@ static void games_scores_dialog_init (GamesScoresDialog *self)
 
   gtk_window_set_destroy_with_parent (GTK_WINDOW (self), TRUE);
 
+  gtk_widget_grab_focus (self->_priv->combo);
+
   gtk_widget_show_all (vbox);
   gtk_widget_hide (self->_priv->hdiv);
   gtk_widget_hide (self->_priv->message);
